Crate ansi_colors

Crate ansi_colors 

Modules

colors
this mod public use is for you to understand the ansi escape codes:)

Structs

ColouredStr
This struct is the main way to utilize the coloring sceme in this crate.