Crate ansi_colors
ansi_
colors
0.3.0
All Items
Crate Items
Modules
Structs
Crate
ansi_
colors
Modules

colors
this mod public use is for you to understand the ansi escape codes:)
Structs

Coloured
Str
This struct is the main way to utilize the coloring sceme in this crate.